import { renderless, api } from '@opentinyvue/vue-renderless/split/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { IconLeftWard, IconRightward, IconStretchUpright, IconStretchCrosswise } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconLeftWard: IconLeftWard(),
    IconRightWard: IconRightward(),
    IconStretchUpright: IconStretchUpright(),
    // 纵向
    IconStretchCrosswise: IconStretchCrosswise()
    // 横向
  },
  emits: ["moving", "mousemove", "mouseup", "moveend", "movestart", "update:modelValue", "left-top-click", "right-bottom-click"],
  props: [].concat(props, ["modelValue", "mode", "leftTopMin", "rightBottomMin", "disabled", "triggerSimple", "collapseLeftTop", "collapseRightBottom", "threeAreas", "scrollable", "border", "rightBottomValue"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    ref: "outerWrapper",
    class: _vm.state.wrapperClasses
  }, [_vm.state.isHorizontal ? _c("div", {
    class: _vm.state.prefix + "-horizontal"
  }, [_c("div", {
    staticClass: "left-pane",
    class: _vm.state.paneClasses,
    style: {
      right: _vm.state.anotherOffset + "%",
      width: _vm.state.anotherOffset !== 100 && _vm.threeAreas ? _vm.state.leftTopPane + "px" : ""
    }
  }, [_vm._t("left")], 2), _c("div", {
    class: [_vm.state.prefix + "-trigger-con", _vm.state.prefix + "-trigger-con-vertical", _vm.disabled ? _vm.state.prefix + "-trigger-con-disabled" : "", _vm.state.isMoving ? _vm.state.prefix + "-trigger-con-drag" : "", _vm.state.offset === 0 && _vm.triggerSimple ? _vm.state.prefix + "-trigger-con-left-active" : "", _vm.triggerSimple ? _vm.state.prefix + "-trigger-con-simple" : ""],
    style: {
      left: _vm.threeAreas ? _vm.state.leftTopPane + "px" : _vm.state.offset + "%"
    },
    on: {
      "mousedown": _vm.handleMousedown
    }
  }, [_vm._t("trigger", function() {
    return [_c("div", {
      class: [_vm.state.prefix + "-trigger", _vm.state.prefix + "-trigger-vertical"]
    }, [!_vm.state.triggerBarConWithLine ? [!_vm.triggerSimple ? _c("div", {
      class: [_vm.state.prefix + "-trigger-bar-con", "vertical"]
    }, _vm._m(0), 0) : _vm._e()] : [!_vm.triggerSimple ? _c("div", {
      class: [_vm.state.prefix + "-trigger-bar-con", "vertical"]
    }, [_c("IconStretchUpright")], 1) : _vm._e()]], 2)];
  }), _vm.triggerSimple ? _c("div", {
    class: [_vm.state.prefix + "-trigger-button", _vm.state.prefix + "-trigger-left-button", _vm.state.offset === 100 ? _vm.state.prefix + "-trigger-button-active" : "", _vm.state.offset === 100 || _vm.collapseLeftTop ? _vm.state.prefix + "-trigger-button-show" : ""],
    on: {
      "mousedown": _vm.buttonMousedown,
      "click": _vm.buttonLeftTopClick
    }
  }, [_c("icon-left-ward", {
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e(), _vm.triggerSimple ? _c("div", {
    class: [_vm.state.prefix + "-trigger-button", _vm.state.prefix + "-trigger-right-button", _vm.state.offset === 0 ? _vm.state.prefix + "-trigger-button-active" : "", _vm.state.offset === 0 || _vm.collapseRightBottom ? _vm.state.prefix + "-trigger-button-show" : ""],
    on: {
      "mousedown": _vm.buttonMousedown,
      "click": _vm.buttonRightBottomClick
    }
  }, [_c("icon-right-ward", {
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e()], 2), _c("div", {
    staticClass: "right-pane",
    class: _vm.state.paneClasses,
    style: {
      left: _vm.threeAreas ? _vm.state.leftTopPane + "px" : _vm.state.offset + "%",
      width: _vm.threeAreas ? "calc(100% - " + _vm.state.leftTopPane + "px)" : ""
    }
  }, [_vm._t("right")], 2)]) : _c("div", {
    class: _vm.state.prefix + "-vertical"
  }, [_c("div", {
    staticClass: "top-pane",
    class: _vm.state.paneClasses,
    style: {
      bottom: _vm.state.anotherOffset + "%",
      height: _vm.state.anotherOffset !== 100 && _vm.threeAreas ? _vm.state.leftTopPane + "px" : ""
    }
  }, [_vm._t("top")], 2), _c("div", {
    class: [_vm.state.prefix + "-trigger-con", _vm.state.prefix + "-trigger-con-horizontal", _vm.disabled ? _vm.state.prefix + "-trigger-con-disabled" : "", _vm.state.isMoving ? _vm.state.prefix + "-trigger-con-drag" : "", _vm.state.offset === 0 && _vm.triggerSimple ? _vm.state.prefix + "-trigger-con-top-active" : "", _vm.triggerSimple ? _vm.state.prefix + "-trigger-con-simple" : ""],
    style: {
      top: _vm.threeAreas ? _vm.state.leftTopPane + "px" : _vm.state.offset + "%"
    },
    on: {
      "mousedown": _vm.handleMousedown
    }
  }, [_vm._t("trigger", function() {
    return [_c("div", {
      class: [_vm.state.prefix + "-trigger", _vm.state.prefix + "-trigger-horizontal"]
    }, [!_vm.state.triggerBarConWithLine ? [!_vm.triggerSimple ? _c("div", {
      class: [_vm.state.prefix + "-trigger-bar-con", "horizontal"]
    }, _vm._m(1), 0) : _vm._e()] : [!_vm.triggerSimple ? _c("div", {
      class: [_vm.state.prefix + "-trigger-bar-con", "horizontal"]
    }, [_c("IconStretchCrosswise")], 1) : _vm._e()]], 2)];
  }), _vm.triggerSimple ? _c("div", {
    class: [_vm.state.prefix + "-trigger-button", _vm.state.prefix + "-trigger-top-button", _vm.state.offset === 100 ? _vm.state.prefix + "-trigger-button-active" : "", _vm.state.offset === 100 || _vm.collapseLeftTop ? _vm.state.prefix + "-trigger-button-show" : ""],
    on: {
      "mousedown": _vm.buttonMousedown,
      "click": _vm.buttonLeftTopClick
    }
  }, [_c("icon-left-ward", {
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e(), _vm.triggerSimple ? _c("div", {
    class: [_vm.state.prefix + "-trigger-button", _vm.state.prefix + "-trigger-bottom-button", _vm.state.offset === 0 ? _vm.state.prefix + "-trigger-button-active" : "", _vm.state.offset === 0 || _vm.collapseRightBottom ? _vm.state.prefix + "-trigger-button-show" : ""],
    on: {
      "mousedown": _vm.buttonMousedown,
      "click": _vm.buttonRightBottomClick
    }
  }, [_c("icon-right-ward", {
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e()], 2), _c("div", {
    staticClass: "bottom-pane",
    class: _vm.state.paneClasses,
    style: {
      top: _vm.threeAreas ? _vm.state.leftTopPane + "px" : _vm.state.offset + "%",
      height: _vm.threeAreas ? "calc(100% - " + _vm.state.leftTopPane + "px)" : ""
    }
  }, [_vm._t("bottom")], 2)])]);
};
var staticRenderFns = [function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _vm._l(3, function(i) {
    return _c("i", {
      key: "trigger-" + i,
      class: _vm.state.prefix + "-trigger-bar"
    });
  });
}, function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _vm._l(3, function(i) {
    return _c("i", {
      key: "trigger-" + i,
      class: _vm.state.prefix + "-trigger-bar"
    });
  });
}];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
